@@ -57,7 +57,7 @@ def _b64UrlEncode(s):
 def slugId():
   """ Generate a taskcluster slugid.  This is a V4 UUID encoded into
   URL-Safe Base64 (RFC 4648, sec 5) with '=' padding removed """
-  return makeB64UrlSafe(_b64encode(str(uuid.uuid4())).replace('=', ''))
+  return makeB64UrlSafe(_b64encode(uuid.uuid4().bytes).replace('=', ''))
 
 
 def _dmpJson(obj, **kwargs):
@@ -259,6 +259,8 @@ class BaseClient(object):
       payload = _kwargs['payload']
       del _kwargs['payload']
       log.debug('We have a payload!')
+      if not payload:
+        raise exceptions.TaskclusterFailure('This method requires a payload kwarg')
 
     apiArgs = self._processArgs(entry['args'], *args, **_kwargs)
     route = self._subArgsInRoute(entry['route'], apiArgs)
@@ -276,6 +278,10 @@ class BaseClient(object):
 
     data = {}
 
+    for arg in list(args) + [kwargs[x] for x in kwargs if x != 'payload']:
+      if not isinstance(arg, basestring):
+        raise exceptions.TaskclusterFailure('Argument is not a string')
+
     # We know for sure that if we don't give enough arguments that the call
     # should fail.  We don't yet know if we should fail because of two many
     # arguments because we might be overwriting positional ones with kw ones
@@ -396,7 +402,7 @@ class BaseClient(object):
     log.debug('Making a %s request to %s', method, url)
     opts = self.options
     cred = opts.get('credentials')
-    if cred and 'clientId' in cred and 'accessToken' in cred:
+    if cred and 'clientId' in cred and 'accessToken' in cred and cred['clientId'] and cred['accessToken']:
       hawkOpts = {
         'credentials': {
           'id': cred['clientId'],
@@ -410,6 +416,9 @@ class BaseClient(object):
     else:
       log.info('Not using hawk!')
       headers = {}
+    if payload:
+      payload = json.dumps(payload)
+      headers['Content-Type'] = 'application/json'
 
     return requests.request(method.upper(), url, data=payload, headers=headers)
 
