@@ -4,6 +4,7 @@ import unittest
 import time
 realTimeTime = time.time
 import datetime
+import uuid
 
 import httmock
 import mock
@@ -112,6 +113,18 @@ class TestProcessArgs(ClientTest):
     with self.assertRaises(exc.TaskclusterFailure):
       self.client._processArgs(['test', 'test2'], 'enough', test='enough')
 
+  def test_invalid_positional_not_string_empty_dict(self):
+    with self.assertRaises(exc.TaskclusterFailure):
+      self.client._processArgs(['a'], {})
+
+  def test_invalid_positional_not_string_non_empty_dict(self):
+    with self.assertRaises(exc.TaskclusterFailure):
+      self.client._processArgs(['a'], {'john': 'ford'})
+
+  def test_invalid_positional_not_string_int(self):
+    with self.assertRaises(exc.TaskclusterFailure):
+      self.client._processArgs(['a'], 4)
+
 
 class TestMakeSingleHttpRequest(ClientTest):
   def test_success_no_payload(self):
@@ -128,7 +141,7 @@ class TestMakeSingleHttpRequest(ClientTest):
   def test_success_payload(self):
     @httmock.all_requests
     def response_content(url, request):
-      self.assertEqual(request.body, 'i=j')
+      self.assertEqual(request.body, '{"i": "j"}')
       return {'status_code': 200, 'content': {'k': 'l'}}
 
     with httmock.HTTMock(response_content):
@@ -319,6 +332,12 @@ class TestMakeApiCall(ClientTest):
 
       patcher.assert_called_once_with('get', 'no_args_with_input', expected_input)
 
+  def test_missing_input_raises(self):
+    with self.assertRaises(exc.TaskclusterFailure):
+      self.client.no_args_with_input({'malformed': 'payload'})
+    with self.assertRaises(exc.TaskclusterFailure):
+      self.client.no_args_with_input()
+
 
 # TODO: I should run the same things through the node client and compare the output
 class TestTopicExchange(ClientTest):
@@ -400,8 +419,8 @@ class TestBuildSignedUrl(ClientTest):
 class TestSlugId(base.TCTest):
   def test_slug_id(self):
     with mock.patch('uuid.uuid4') as p:
-      p.return_value = '8ed7ba5e-380b-4c08-aa9c-1c86382afe23'
-      expected = 'OGVkN2JhNWUtMzgwYi00YzA4LWFhOWMtMWM4NjM4MmFmZTIz'
+      p.return_value = uuid.UUID('bed97923-7616-4ec8-85ed-4b695f67ac2e')
+      expected = 'vtl5I3YWTsiF7UtpX2esLg'
       actual = subject.slugId()
       self.assertEqual(expected, actual)
 
@@ -495,3 +514,27 @@ class TestAuthenticationMockServer(base.TCTest):
     with self.assertRaises(requests.exceptions.RequestException):
       r.raise_for_status()
     self.assertEqual(401, r.status_code)
+
+
+class ProductionTest(base.TCTest):
+
+  def setUp(self):
+    self.i = subject.Index()
+
+  def test_ping(self):
+    result = self.i.ping()
+    self.assertEqual(result['alive'], True)
+
+  def test_listnamespace(self):
+    result = self.i.listNamespaces('')
+    assert 'namespaces' in result
+
+  def test_insert_to_index(self):
+    payload = {
+      'taskId': 'a' * 22,
+      'rank': 1,
+      'data': {'test': 'data'},
+      'expires': '2015-09-09T19:19:15.879Z'
+    }
+    result = self.i.insertTask('testing', payload=payload)
+    self.assertEqual(payload['expires'], result['expires'])
